#!/usr/bin/env ruby

class SiteRecord < Struct.new(:site, :warn_count, :error_count)
	def to_s
		site
	end
end

records = []

ARGF.each_line do |line|
	match = /(.+) ([\d\?]+) ([\d\?]+)/.match(line)

	records << SiteRecord.new(match[1], match[2], match[3])
end

knowns = records.select { |r| r.warn_count != '?' }

by_errors = knowns.sort_by { |r| r.error_count.to_i }.reverse

errors = knowns.map(&:error_count).map(&:to_i)

by_errors.each do |r|
	puts r.error_count
end

nerrors = errors.select { |e| e < 1000 }
nmean = nerrors.inject { |sum, i| sum + i }.to_f / nerrors.size
mean = errors.inject { |sum, i| sum + i }.to_f / errors.size
freq = errors.inject(Hash.new(0)) { |h, v| h[v] += 1 ; h }
mode = errors.max_by { |v| freq[v] }
range = errors.max - errors.min
stddev = Math.sqrt(errors.inject { |acc, i| acc + (i - mean)**2 } / (errors.size - 1).to_f)

puts "mean: #{mean}, nmean: #{nmean}, mode: #{mode}, range: #{range}, stddev: #{stddev}"

spans = []

(0..80).step(20) do |i|
	spans << errors.select { |e| e >= i && e < i + 20 }.size
end

puts spans
